@@ -9,9 +9,9 @@
 #include "dbaccess.h"
 
 #include <AkonadiCore/AttributeFactory>
-#include <QSqlQuery>
 #include <QDialogButtonBox>
 #include <QSqlError>
+#include <QSqlQuery>
 
 using namespace Akonadi;
 
@@ -45,16 +45,16 @@ bool TagPropertiesDialog::changed() const
 
 void TagPropertiesDialog::setupUi()
 {
-    auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &TagPropertiesDialog::slotAccept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &TagPropertiesDialog::reject);
 
-    auto *widget = new QWidget(this);
+    auto widget = new QWidget(this);
     ui.setupUi(widget);
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(widget);
     mainLayout->addWidget(buttonBox);
 
@@ -101,10 +101,11 @@ void TagPropertiesDialog::setupUi()
             // resource than in the current context. Since Akonadi Console has
             // not resource context at all, we need to retrieve the IDs the hard way
             QSqlQuery query(DbAccess::database());
-            query.prepare(QStringLiteral("SELECT ResourceTable.name, TagRemoteIdResourceRelationTable.remoteId "
-                                         "FROM TagRemoteIdResourceRelationTable "
-                                         "LEFT JOIN ResourceTable ON ResourceTable.id = TagRemoteIdResourceRelationTable.resourceId "
-                                         "WHERE TagRemoteIdResourceRelationTable.tagid = ?"));
+            query.prepare(
+                QStringLiteral("SELECT ResourceTable.name, TagRemoteIdResourceRelationTable.remoteId "
+                               "FROM TagRemoteIdResourceRelationTable "
+                               "LEFT JOIN ResourceTable ON ResourceTable.id = TagRemoteIdResourceRelationTable.resourceId "
+                               "WHERE TagRemoteIdResourceRelationTable.tagid = ?"));
             query.addBindValue(mTag.id());
             if (query.exec()) {
                 while (query.next()) {
@@ -264,11 +265,12 @@ void TagPropertiesDialog::slotAccept()
 
     if (mTag.isValid() && !mRemovedRIDs.isEmpty()) {
         QSqlQuery query(DbAccess::database());
-        QString queryStr = QStringLiteral("DELETE FROM TagRemoteIdResourceRelationTable "
-                                          "WHERE tagId = ? AND "
-                                          "resourceId IN (SELECT id "
-                                          "FROM ResourceTable "
-                                          "WHERE ");
+        QString queryStr = QStringLiteral(
+            "DELETE FROM TagRemoteIdResourceRelationTable "
+            "WHERE tagId = ? AND "
+            "resourceId IN (SELECT id "
+            "FROM ResourceTable "
+            "WHERE ");
         QStringList conds;
         for (int i = 0; i < mRemovedRIDs.count(); ++i) {
             conds << QStringLiteral("name = ?");
